# Description:
Topsis Module is used in Decision Making.

## Installation
```pip install topsis-raunak-102017148```

## How to use it? 
Use topsis function pass a dataframe.

## License
© 2023 Raunak Kumar

This repository is licensed under the MIT license.
See LICENSE for details.